@@ -13,7 +13,7 @@ _TreeDocumentContent = TypeVar('_TreeDocumentContent', bound='TreeDocumentConten
 class TreeDocumentContent(TreeNode, AbstractTreeDocumentContent):
     __slots__ = (
         '_node_type', '_text', '_text_translations', '_markup', '_original_text', '_hidden',
-        '_text_references', '_concat_text_len', '_id2span', '_spans_tree', '_language'
+        '_text_references', '_concat_text_len', '_id2span', '_lazy_spans_tree', '_language'
     )
 
     DOCUMENT_SEPARATOR = '\n'  # Must be one whitespace character as methods implementations use this condition
@@ -45,7 +45,14 @@ class TreeDocumentContent(TreeNode, AbstractTreeDocumentContent):
             pointer += node._concat_text_len + len(TreeDocumentContent.DOCUMENT_SEPARATOR)
         self._concat_text_len = pointer - len(TreeDocumentContent.DOCUMENT_SEPARATOR)
 
-        self._spans_tree = IntervalTree.from_tuples((s.start_idx, s.end_idx, n_id) for n_id, s in self._id2span.items() if s.length != 0)
+        self._lazy_spans_tree = None
+
+    @property
+    def _spans_tree(self):
+        if self._lazy_spans_tree is None:
+            self._lazy_spans_tree = IntervalTree.from_tuples(
+                (s.start_idx, s.end_idx, n_id) for n_id, s in self._id2span.items() if s.length != 0)
+        return self._lazy_spans_tree
 
     @property
     def type(self) -> NodeType:
